package com.fs.live.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.common.utils.DateUtils;
import com.fs.live.domain.LiveAnchor;
import com.fs.live.mapper.LiveAnchorMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveGoodsMapper;
import com.fs.live.domain.LiveGoods;
import com.fs.live.service.ILiveGoodsService;

/**
 * 直播商品Service业务层处理
 * 
 * @author fs
 * @date 2025-01-17
 */
@Service
public class LiveGoodsServiceImpl extends ServiceImpl<LiveGoodsMapper, LiveGoods> implements ILiveGoodsService
{
    @Autowired
    private LiveGoodsMapper liveGoodsMapper;

    /**
     * 查询直播商品
     * 
     * @param goodsId 直播商品主键
     * @return 直播商品
     */
    @Override
    public LiveGoods selectLiveGoodsByGoodsId(Long goodsId)
    {
        return liveGoodsMapper.selectLiveGoodsByGoodsId(goodsId);
    }

    /**
     * 查询直播商品列表
     * 
     * @param liveGoods 直播商品
     * @return 直播商品
     */
    @Override
    public List<LiveGoods> selectLiveGoodsList(LiveGoods liveGoods)
    {
        return liveGoodsMapper.selectLiveGoodsList(liveGoods);
    }

    /**
     * 新增直播商品
     * 
     * @param liveGoods 直播商品
     * @return 结果
     */
    @Override
    public int insertLiveGoods(LiveGoods liveGoods)
    {
        liveGoods.setCreateTime(DateUtils.getNowDate());
        return liveGoodsMapper.insertLiveGoods(liveGoods);
    }

    /**
     * 修改直播商品
     * 
     * @param liveGoods 直播商品
     * @return 结果
     */
    @Override
    public int updateLiveGoods(LiveGoods liveGoods)
    {
        liveGoods.setUpdateTime(DateUtils.getNowDate());
        return liveGoodsMapper.updateLiveGoods(liveGoods);
    }

    /**
     * 批量删除直播商品
     * 
     * @param goodsIds 需要删除的直播商品主键
     * @return 结果
     */
    @Override
    public int deleteLiveGoodsByGoodsIds(Long[] goodsIds)
    {
        return liveGoodsMapper.deleteLiveGoodsByGoodsIds(goodsIds);
    }

    /**
     * 删除直播商品信息
     * 
     * @param goodsId 直播商品主键
     * @return 结果
     */
    @Override
    public int deleteLiveGoodsByGoodsId(Long goodsId)
    {
        return liveGoodsMapper.deleteLiveGoodsByGoodsId(goodsId);
    }
}
